import React, { useState } from "react";
import cx from "classnames";

import Toggle from "../controls/Toggle";
import Identifier from "./Identifier";

import styles from "./ResultListItem.module.scss";

const ResultListItem = ({ identifier, title, children = null, className = null }) => {
    const [isExpanded, setIsExpanded] = useState(false);

    const titleElement = <span className={styles.Title}>{title}</span>;
    const identifierElement = <Identifier identifier={identifier} />;

    return (
        <li className={cx(styles.ResultListItem, !!children && styles.Expandable, className)}>
            {children ? (
                <>
                    <Toggle isExpanded={isExpanded} setIsExpanded={setIsExpanded} className={styles.Toggle}>
                        <span className={styles.Title}>{titleElement}</span>
                    </Toggle>
                    {identifierElement}
                    {isExpanded && <div className={styles.Contents}>{children}</div>}
                </>
            ) : (
                <>
                    {titleElement}
                    {identifierElement}
                </>
            )}
        </li>
    );
};

export default ResultListItem;
