import React from "react";
import { Model, LineChart, PivotTable } from "@gooddata/react-components";
import { Container, Row, Col } from "react-grid-system";

const ParametricDashboardBody = ({
    catalogueData,
    measures,
    primaryAttribute,
    dateAttribute,
    dateFilters,
}) => {
    const measureModels = measures.map(measure => Model.measure(measure));
    const primaryAttributeModel = Model.attribute(primaryAttribute);
    const dateAttributeModel = dateAttribute && Model.attribute(dateAttribute);
    return (
        <Container fluid xs sm md lg>
            <Row>
                <Col style={{ height: 300 }}>
                    <LineChart
                        projectId={catalogueData.projectId}
                        measures={measureModels}
                        viewBy={[primaryAttributeModel]}
                        trendBy={dateAttributeModel}
                        filters={dateFilters}
                    />
                </Col>
            </Row>
            <Row>
                <Col>
                    <PivotTable
                        projectId={catalogueData.projectId}
                        measures={measureModels}
                        rows={[primaryAttributeModel]}
                        filters={dateFilters}
                    />
                </Col>
            </Row>
        </Container>
    );
};

export default ParametricDashboardBody;
