import React from "react";
import { ColumnChart, Model } from "@gooddata/react-components";
import C from "../../constants";

import styles from "./Visualizations.module.scss";
import ReferencesLink from "./ReferencesLink";

const config = {
    legend: {
        position: "bottom",
    },
};
const grossProfitMeasure = Model.measure(C.measures.grossProfit);
const locationStateAttributeDF = Model.attribute(C.attributeDisplayForms.locationState);
const locationNameAttributeDF = Model.attribute(C.attributeDisplayForms.locationName);
const sortByGrossProfit = Model.attributeSortItem(
    locationStateAttributeDF.visualizationAttribute.localIdentifier,
    "desc",
).aggregation("sum");

const ByStateColumnChart = ({ filters }) => {
    return (
        <div className={styles.ChartBlock}>
            <div className={styles.Chart}>
                <ColumnChart
                    filters={filters}
                    projectId={C.projectId}
                    measures={[grossProfitMeasure]}
                    viewBy={[locationStateAttributeDF]}
                    stackBy={locationNameAttributeDF}
                    sortBy={[sortByGrossProfit]}
                    config={config}
                />
            </div>
            <ReferencesLink href="https://sdk.gooddata.com/gooddata-ui/docs/column_chart_component.html">
                ColumnChart component
            </ReferencesLink>
        </div>
    );
};

export default ByStateColumnChart;
