import React from "react";
import { Execute, ErrorComponent, LoadingComponent } from "@gooddata/react-components";
import { numberFormat } from "@gooddata/numberjs";

import C from "../../constants";
import { USStateCodes } from "./constants";
import USAMap from "./USAMap";
import ReferencesLink from "./ReferencesLink";

import styles from "./Visualizations.module.scss";

const USStateNameMap = Object.assign(
    {},
    ...Object.keys(USStateCodes).map(stateCode => ({ [USStateCodes[stateCode]]: stateCode })),
);
// const grossProfitMeasure = Model.measure(C.measures.grossProfit);
// const locationStateAttributeDF = Model.attribute(C.attributeDisplayForms.locationState);
// TODO: generate AFM from Model

const ByStateMap = ({ filters }) => {
    const execution = {
        execution: {
            afm: {
                measures: [
                    {
                        localIdentifier: "m_3",
                        definition: {
                            measure: {
                                item: {
                                    identifier: C.measures.grossProfit,
                                },
                            },
                        },
                    },
                ],
                attributes: [
                    {
                        displayForm: {
                            identifier: C.attributeDisplayForms.locationState,
                        },
                        localIdentifier: "va_0",
                    },
                ],
                filters,
            },
            resultSpec: {
                dimensions: [
                    {
                        itemIdentifiers: ["measureGroup"],
                    },
                    {
                        itemIdentifiers: ["va_0"],
                    },
                ],
            },
        },
    };

    return (
        <div className={styles.ChartBlock}>
            <h3 className={styles.Heading}>Profit by State Map</h3>
            <div className={styles.Map}>
                <Execute
                    projectId={C.projectId}
                    afm={execution.execution.afm}
                    resultSpec={execution.execution.resultSpec}
                >
                    {({ error, isLoading, result }) => {
                        if (error) {
                            return <ErrorComponent code={error.code} message={error.message} />;
                        }
                        if (isLoading || !result) {
                            return <LoadingComponent />;
                        }
                        const rowIndex = 0;
                        const measureDimensionIndex = 0;
                        const stateDimensionIndex = 1;
                        const measureGroupIndex = 0;
                        const measureIndex = 0;
                        const attributeIndex = 0;
                        const dataValues = result.executionResult.data[rowIndex];
                        const dataMap = Object.assign(
                            {},
                            ...dataValues.map((dataValue, dataIndex) => {
                                const stateName =
                                    result.executionResult.headerItems[stateDimensionIndex][attributeIndex][
                                        dataIndex
                                    ].attributeHeaderItem.name;
                                const stateCode = USStateNameMap[stateName];
                                return {
                                    [stateCode]: parseFloat(dataValue),
                                };
                            }),
                        );
                        const dataFormat =
                            result.executionResponse.dimensions[measureDimensionIndex].headers[
                                measureGroupIndex
                            ].measureGroupHeader.items[measureIndex].measureHeaderItem.format;
                        return (
                            <>
                                <USAMap
                                    stateData={dataMap}
                                    colorFrom="#000"
                                    colorTo="#14b2e2"
                                    formatNumber={value => numberFormat(value, dataFormat)}
                                />
                            </>
                        );
                    }}
                </Execute>
            </div>
            <ReferencesLink href="https://sdk.gooddata.com/gooddata-ui/docs/execute_component.html">
                Execute component
            </ReferencesLink>
        </div>
    );
};

export default ByStateMap;
