import React, { useCallback } from "react";
import { PivotTable, Model } from "@gooddata/react-components";
import C from "../../constants";

import styles from "./Visualizations.module.scss";
import ReferencesLink from "./ReferencesLink";

const totalSalesMeasure = Model.measure(C.measures.totalSales);
const averageCheckSize = Model.measure(C.measures.averageCheckSize).format("$#,##0.00");
const employeeNameAttributeDF = Model.attribute(C.attributeDisplayForms.employeeName);
const sortByTotalSales = Model.measureSortItem(totalSalesMeasure.measure.localIdentifier, "desc");
const drillByEmployeeName = {
    identifier: C.attributeDisplayForms.employeeName,
};

const EmployeeTable = ({ filters, onDrill }) => {
    const onFiredDrillEventCallback = useCallback(
        ({
            drillContext: {
                intersection: [_attribute, employee],
            },
        }) => onDrill(employee),
        [onDrill],
    );

    return (
        <div className={styles.ChartBlock}>
            <h3 className={styles.Heading}>Sales by Employee</h3>
            <div className={styles.Table}>
                <PivotTable
                    filters={filters}
                    projectId={C.projectId}
                    measures={[totalSalesMeasure, averageCheckSize]}
                    rows={[employeeNameAttributeDF]}
                    sortBy={[sortByTotalSales]}
                    drillableItems={[drillByEmployeeName]}
                    onFiredDrillEvent={onFiredDrillEventCallback}
                />
            </div>
            <ReferencesLink href="https://sdk.gooddata.com/gooddata-ui/docs/pivot_table_component.html">
                PivotTable component
            </ReferencesLink>
        </div>
    );
};

export default EmployeeTable;
