import React, { useCallback, useEffect, useState } from "react";
import { ErrorComponent } from "@gooddata/react-components";
import CatalogueSelect from "./CatalogueSelect";
import MeasureByAttributeChangeExecutor from "./MeasureByAttributeChangeExecutor";
import {
    collectAttributeDisplayForms,
    getAttributeDisplayFormByIdentifier,
    getMeasureByIdentifier,
} from "../../../utils/catalogue";
import styles from "./MeasureByAttributeChangeWidget.module.scss";

const MeasureByAttributeChangeWidgetBody = ({
    catalogueData,
    attributeDisplayFormIdentifier,
    isAttributeDisplayFormFixed,
    measureIdentifier,
    isMeasureFixed,
    popAttributeIdentifier,
    itemsPerPage,
    filters,
}) => {
    const [selectedMeasure, setSelectedMeasure] = useState(null);
    const [selectedAttributeDF, setSelectedAttributeDF] = useState(null);

    // Set default selected measure after catalogueSource is resolved
    useEffect(() => {
        if (catalogueData) {
            setSelectedMeasure(
                measureIdentifier !== null
                    ? getMeasureByIdentifier(catalogueData, measureIdentifier)
                    : Object.values(catalogueData.measures)[0],
            );
        }
    }, [catalogueData, filters, measureIdentifier]);

    // Set default selected attribute after catalogueSource is resolved
    useEffect(() => {
        if (catalogueData) {
            setSelectedAttributeDF(
                attributeDisplayFormIdentifier !== null
                    ? getAttributeDisplayFormByIdentifier(catalogueData, attributeDisplayFormIdentifier)
                    : Object.values(catalogueData.attributes)[0].content.displayForms[0],
            );
        }
    }, [catalogueData, filters, attributeDisplayFormIdentifier]);

    const onSelectedMeasureChange = useCallback(measureItem => {
        setSelectedMeasure((measureItem && measureItem.value) || null);
    }, []);

    const onSelectedAttributeDFIdentifierChange = useCallback(attributeDFItem => {
        setSelectedAttributeDF((attributeDFItem && attributeDFItem.value) || null);
    }, []);

    if (!selectedAttributeDF && attributeDisplayFormIdentifier && isAttributeDisplayFormFixed) {
        return (
            <div className={styles.Main}>
                <ErrorComponent
                    message={`Attribute Display Form with identifier ${attributeDisplayFormIdentifier} was not found in catalogue.`}
                />
            </div>
        );
    }
    if (!selectedMeasure && measureIdentifier && isMeasureFixed) {
        return (
            <div className={styles.Main}>
                <ErrorComponent
                    message={`Measure with identifier ${attributeDisplayFormIdentifier} was not found in catalogue.`}
                />
            </div>
        );
    }
    return (
        <>
            <div className={styles.Pickers}>
                {!isMeasureFixed && (
                    <CatalogueSelect
                        selectedCatalogueItem={selectedMeasure}
                        catalogueList={Object.values(catalogueData.measures)}
                        onChange={onSelectedMeasureChange}
                        placeholder="Measure"
                    />
                )}
                {!isAttributeDisplayFormFixed && (
                    <CatalogueSelect
                        selectedCatalogueItem={selectedAttributeDF}
                        catalogueList={collectAttributeDisplayForms(catalogueData.attributes)}
                        onChange={onSelectedAttributeDFIdentifierChange}
                        placeholder="Attribute"
                    />
                )}
            </div>
            <div className={styles.Main}>
                {selectedMeasure && selectedAttributeDF ? (
                    <MeasureByAttributeChangeExecutor
                        catalogue={catalogueData}
                        filters={filters}
                        catalogueMeasure={selectedMeasure}
                        popAttributeIdentifier={popAttributeIdentifier}
                        catalogueAttributeDisplayForm={selectedAttributeDF}
                        itemsPerPage={itemsPerPage}
                    />
                ) : <div className={styles.NoMeasureOrAttributeSelected}>Select a measure and an attribute</div>}
            </div>
        </>
    );
};

export default MeasureByAttributeChangeWidgetBody;
