import React from "react";
import IconChevronUp from "../../icons/IconChevronUp";
import IconChevronDown from "../../icons/IconChevronDown";

import styles from "./Paging.module.scss";

const isFirstPage = ({ offset }, dimensionIndex = 0) => offset[dimensionIndex] === 0;

const isLastPage = ({ offset, count, total }, dimensionIndex = 0) =>
    offset[dimensionIndex] + count[dimensionIndex] >= total[dimensionIndex];

const Paging = ({ currentPaging, getPage, limit }) => {
    const { offset, total } = currentPaging;
    const rowIndex = 0;
    const currentPage = offset[rowIndex] / limit[rowIndex] + 1;
    const totalPages = Math.ceil(total[rowIndex] / limit[rowIndex]);

    const isCurrentPageFirst = isFirstPage(currentPaging);
    const isCurrentPageLast = isLastPage(currentPaging);
    const isPagingNeeded = !(isCurrentPageFirst && isCurrentPageLast);

    return isPagingNeeded ? (
        <div className={styles.Paging}>
            Page {currentPage} of {totalPages}&ensp;
            <button
                disabled={isCurrentPageFirst}
                onClick={() =>
                    getPage({
                        offset: [offset[rowIndex] - limit[rowIndex]],
                        limit,
                    })
                }
                className={styles.PagingButton}
            >
                <IconChevronUp className={styles.PagingIcon} />
            </button>
            &ensp;
            <button
                disabled={isCurrentPageLast}
                onClick={() =>
                    getPage({
                        offset: [offset[rowIndex] + limit[rowIndex]],
                        limit,
                    })
                }
                className={styles.PagingButton}
            >
                <IconChevronDown className={styles.PagingIcon} />
            </button>
        </div>
    ) : null;
};

export default Paging;
