import React, { memo } from "react";
import { Model } from "@gooddata/react-components";
import C from "../../../constants";
import TrendWidgetMeasure from "./TrendWidgetMeasure";
import GranularityPicker from "../../controls/GranularityPicker";
import TrendWidgetGraph from "./TrendWidgetGraph";

import styles from "./TrendWidgetBody.module.scss";

const TrendWidgetBody = ({
    projectId,
    filters,
    measures,
    selectedMeasures,
    setSelectedMeasure,
    setIsMeasureActive,
    addMeasure,
    canAddMeasure,

    granularities,
    selectedGranularity,
    setSelectedGranularity,

    trendBy,

    readOnly,
}) => {
    const availableMeasures = Object.values(measures).filter(
        measure => !selectedMeasures.some(({ measureId }) => measureId === measure.meta.identifier),
    );

    const firstEmptyIndex = Math.max(0, selectedMeasures.findIndex(m => !m.measureId));
    const hasNoActiveMeasures = selectedMeasures.every(m => !m.measureId || !m.isActive);

    const activeMeasures = selectedMeasures
        .filter(measure => measure.isActive)
        .map(measure => Model.measure(measure.measureId));
    const activeIndexes = selectedMeasures
        .map((measure, measureIndex) => (measure.isActive ? measureIndex : null))
        .filter(index => index !== null);
    const colors = activeIndexes.map(index => C.brandColors[index % C.brandColors.length]);

    return (
        <div>
            <div className={styles.Tabs}>
                {selectedMeasures.map((measure, index) => {
                    const { measureId, isActive } = measure || {
                        measureId: "",
                        isActive: false,
                    };
                    return (
                        <TrendWidgetMeasure
                            projectId={projectId}
                            key={measureId || index}
                            isActive={isActive}
                            isDisabled={!(measureId || index === firstEmptyIndex)}
                            onIsActiveChange={isActive => {
                                if (measureId) {
                                    setIsMeasureActive(index, isActive);
                                }
                            }}
                            availableMeasures={availableMeasures}
                            onSelectedMeasureChange={id => setSelectedMeasure(index, id)}
                            selectedMeasure={measures[measureId]}
                            filters={filters}
                            color={C.brandColors[index % C.brandColors.length]}
                            readOnly={readOnly}
                        />
                    );
                })}

                {canAddMeasure && !readOnly && (
                    <button
                        type="button"
                        className={styles.AddMeasure}
                        onClick={addMeasure}
                        title="Add measure"
                    >
                        +
                    </button>
                )}
            </div>
            <GranularityPicker
                className={styles.GranularityPicker}
                onChange={setSelectedGranularity}
                granularities={granularities}
                selectedGranularity={selectedGranularity}
            />
            {hasNoActiveMeasures ? (
                <div className={styles.NoActiveMeasures}>Select or enable some measure</div>
            ) : (
                <TrendWidgetGraph
                    filters={filters}
                    projectId={projectId}
                    activeMeasures={activeMeasures}
                    colors={colors}
                    trendBy={trendBy}
                />
            )}
        </div>
    );
};

export default memo(TrendWidgetBody);
