import flatMap from "lodash/flatMap";
import { Model } from "@gooddata/react-components";
import sdk from "@gooddata/gooddata-js";

const dateDataSetUri = projectId => `/gdc/internal/projects/${projectId}/loadDateDataSets`;

export const getDateAttributeForGranularity = (catalogueContextData, granularity) => {
    const { availableDateAttributes } = catalogueContextData.dateDataSets[
        catalogueContextData.defaultDateDataSet
    ];
    const relevantAttribute = availableDateAttributes.find(attribute => attribute.type === granularity);

    return relevantAttribute && Model.attribute(relevantAttribute.defaultDisplayFormMeta.identifier);
};

export const getGranularitiesForDateDataSet = dateDataSet =>
    dateDataSet.availableDateAttributes.map(a => a.type);

export const getAvailableDateDataSets = projectId =>
    sdk.xhr
        .post(dateDataSetUri(projectId), {
            data: {
                dateDataSetsRequest: {
                    includeUnavailableDateDataSetsCount: false,
                    includeAvailableDateAttributes: true,
                    bucketItems: [],
                    requiredDataSets: { type: "PRODUCTION" },
                },
            },
        })
        .then(response => response.data.dateDataSetsResponse.dateDataSets)
        .catch(() => []);

export const getDateDisplayFormsFor = (dateDataSets, projectId) => {
    const dateAttributeUris = flatMap(dateDataSets, dateDataSet =>
        dateDataSet.availableDateAttributes.map(attribute => attribute.attributeMeta.uri),
    );

    return sdk.md.getObjects(projectId, dateAttributeUris).then(data =>
        data.reduce((attributeMap, { attribute: { meta, content } }) => {
            attributeMap[meta.uri] = content.displayForms;
            return attributeMap;
        }, {}),
    );
};

export const normalizeDateDataSets = (dateDataSets, dateAttributeDisplayForms) => {
    const normalized = dateDataSets.reduce((dataSetMap, dataSet) => {
        dataSetMap[dataSet.meta.identifier] = dataSet;
        return dataSetMap;
    }, {});
    // assign displayForms to attributes
    Object.values(normalized).forEach(dateDataSet =>
        dateDataSet.availableDateAttributes.forEach(attribute => {
            attribute.displayForms = dateAttributeDisplayForms[attribute.attributeMeta.uri];
        }),
    );
    return normalized;
};
